@@ -14,12 +14,16 @@ class LastUsedOrderedDict(OrderedDict):
         return self[key]
 
 
-if __name__ == '__main__':
+def test():
     d = LastUsedOrderedDict()
-    d['1'] = 1
-    d['2'] = 2
+    d["1"] = 1
+    d["2"] = 2
     print(d)
-    print(d.pick('1'))
+    print(d.pick("1"))
     print(d)
-    d['2'] = 3
+    d["2"] = 3
     print(d)
+
+
+if __name__ == "__main__":
+    test()
