@@ -5,6 +5,7 @@ import traceback
 
 # https://stackoverflow.com/questions/13210436/get-full-traceback
 
+
 class FauxTb(object):
     def __init__(self, tb_frame, tb_lineno, tb_next):
         self.tb_frame = tb_frame
@@ -12,7 +13,7 @@ class FauxTb(object):
         self.tb_next = tb_next
 
 
-def current_stack(skip=0):
+def get_current_stack(skip=0):
     try:
         1 / 0
     except ZeroDivisionError:
@@ -37,31 +38,26 @@ def extend_traceback(tb, stack):
 def full_exc_info():
     """Like sys.exc_info, but includes the full traceback."""
     t, v, tb = sys.exc_info()
-    full_tb = extend_traceback(tb, current_stack(1))
+    full_tb = extend_traceback(tb, get_current_stack(1))
     return t, v, full_tb
 
 
-if __name__ == '__main__':
-    import logging
-
-
+def test():
     def func():
         try:
-            raise Exception('Dummy')
+            raise Exception("Dummy")
         except Exception as e:
             t, v, full_tb = full_exc_info()
             print(t)
             print(v)
             print(full_tb)
-
             print(traceback.format_exc())
-            # _logging.error("Something awful happened!", exc_info=full_exc_info())
-            # _logging.error("Something awful happened!", exc_info=e)
-            # print(traceback.format_exc())
-
 
     def func2():
         func()
 
-
     func2()
+
+
+if __name__ == "__main__":
+    test()
